@@ -10,4 +10,7 @@ from ._cmd_parse_chassis_hardware import get_chassis_hardware
 from ._cmd_parse_arp_table import get_arp_table
 from ._cmd_parse_running_interfaces import get_interfaces_running
 from ._cmd_parse_version import get_version
-from ._cmd_parse_running_system import get_running_system
\ No newline at end of file
+from ._cmd_parse_running_system import get_running_system
+from ._cmd_parse_running_routing_instances import get_instances_running
+from ._cmd_parse_running_bgp import get_instances_bgps
+from .jpw_cracker import juniper_decrypt, juniper_encrypt
\ No newline at end of file
